==> xmlbuilder-0.1.0.tgz: package/lib/XMLBuilder.js <==
(function() {
  var XMLBuilder, XMLFragment;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  XMLFragment = require('./XMLFragment');
  XMLBuilder = (function() {
    __extends(XMLBuilder, XMLFragment);
    function XMLBuilder() {
      XMLBuilder.__super__.constructor.call(this, null, '', {}, '');
    }
    XMLBuilder.prototype.begin = function(name, xmldec, doctype, options) {
      var att, child, root;
      if (!(name != null)) {
        throw new Error("Root element needs a name");
      }
      this.children = [];
      name = '' + name || '';
      if ((xmldec != null) && !(xmldec.version != null)) {
        throw new Error("Version number is required");
      }
      if ((doctype != null) && !(doctype.name != null)) {
        throw new Error("Document name is required");
      }
      if (xmldec != null) {
        xmldec.version = '' + xmldec.version || '';
        if (!xmldec.version.match(this.val.VersionNum)) {
          throw new Error("Invalid version number: " + xmldec.version);
        }
        att = {
          version: xmldec.version
        };
        if (xmldec.encoding != null) {
          xmldec.encoding = '' + xmldec.encoding || '';
          if (!xmldec.encoding.match(this.val.EncName)) {
            throw new Error("Invalid encoding: " + xmldec.encoding);
          }
          att.encoding = xmldec.encoding;
        }
        if (xmldec.standalone != null) {
          att.standalone = xmldec.standalone ? "yes" : "no";
        }
        child = new XMLFragment(this, '?xml', att);
        this.children.push(child);
      }
      if (doctype != null) {
        doctype.name = '' + doctype.name || '';
        if (!String(doctype.name).match("^" + this.val.Name + "$")) {
          throw new Error("Invalid document name: " + doctype.name);
        }
        att = {
          name: doctype.name
        };
        if (doctype.ext != null) {
          doctype.ext = '' + doctype.ext || '';
          if (!String(doctype.ext).match("^" + this.val.ExternalID + "$")) {
            throw new Error("Invalid external ID: " + doctype.ext);
          }
          att.ext = doctype.ext;
        }
        child = new XMLFragment(this, '!DOCTYPE', att);
        this.children.push(child);
      }
      root = new XMLFragment(this, name, {});
      this.children.push(root);
      return root;
    };
    XMLBuilder.prototype.toString = function(options) {
      var child, r, _i, _len, _ref;
      r = '';
      _ref = this.children;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        child = _ref[_i];
        r += child.toString(options);
      }
      return r;
    };
    return XMLBuilder;
  })();
  module.exports = XMLBuilder;
}).call(this);

==> xmlbuilder-0.1.1.tgz: package/lib/XMLBuilder.js <==
(function() {
  var XMLBuilder, XMLFragment;
  var __hasProp = Object.prototype.hasOwnProperty, __extends = function(child, parent) {
    for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; }
    function ctor() { this.constructor = child; }
    ctor.prototype = parent.prototype;
    child.prototype = new ctor;
    child.__super__ = parent.prototype;
    return child;
  };
  XMLFragment = require('./XMLFragment');
  XMLBuilder = (function() {
    __extends(XMLBuilder, XMLFragment);
    function XMLBuilder() {
      XMLBuilder.__super__.constructor.call(this, null, '', {}, '');
    }
    XMLBuilder.prototype.begin = function(name, xmldec, doctype, options) {
      var att, child, root;
      if (!(name != null)) {
        throw new Error("Root element needs a name");
      }
      this.children = [];
      name = '' + name || '';
      if ((xmldec != null) && !(xmldec.version != null)) {
        throw new Error("Version number is required");
      }
      if ((doctype != null) && !(doctype.name != null)) {
        throw new Error("Document name is required");
      }
      if (xmldec != null) {
        xmldec.version = '' + xmldec.version || '';
        if (!xmldec.version.match(/1\.[0-9]+/)) {
          throw new Error("Invalid version number: " + xmldec.version);
        }
        att = {
          version: xmldec.version
        };
        if (xmldec.encoding != null) {
          xmldec.encoding = '' + xmldec.encoding || '';
          if (!xmldec.encoding.match(/[A-Za-z](?:[A-Za-z0-9._-]|-)*/)) {
            throw new Error("Invalid encoding: " + xmldec.encoding);
          }
          att.encoding = xmldec.encoding;
        }
        if (xmldec.standalone != null) {
          att.standalone = xmldec.standalone ? "yes" : "no";
        }
        child = new XMLFragment(this, '?xml', att);
        this.children.push(child);
      }
      if (doctype != null) {
        doctype.name = '' + doctype.name || '';
        att = {
          name: doctype.name
        };
        if (doctype.ext != null) {
          doctype.ext = '' + doctype.ext || '';
          att.ext = doctype.ext;
        }
        child = new XMLFragment(this, '!DOCTYPE', att);
        this.children.push(child);
      }
      root = new XMLFragment(this, name, {});
      this.children.push(root);
      return root;
    };
    XMLBuilder.prototype.toString = function(options) {
      var child, r, _i, _len, _ref;
      r = '';
      _ref = this.children;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        child = _ref[_i];
        r += child.toString(options);
      }
      return r;
    };
    return XMLBuilder;
  })();
  module.exports = XMLBuilder;
}).call(this);
